function [ tv, uv ] = runge_kutta_4( fun, y0, t0, tf, Nh )
% RUNGE_KUTTA_4 Runge-Kutta 4, explicit method for the scalar ODE in the 
% form:
% y'(t) = f(t,y(t)),  t \in (t0,tf)
% y(0) = y_0
%
%  [ tv, uv ] = runge_kutta_4( fun, y0, t0, tf, Nh )
%  Inputs: fun    = function handle for f(t,y), fun = @(t,y) ...
%          y0     = initial value
%          t0     = initial time
%          tf     = final time
%          Nh     = number of time subintervals
%  Output: tv     = vector of time steps (1 x (Nh+1))
%          uv     = vector of approximate solution at times tv
%

return
